==> skrooge-0.7.2.tar.bz2: skrooge-0.7.2/skrooge_monthly/skgmonthlyboardwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGMONTHLYBOARDWIDGET_H
#define SKGMONTHLYBOARDWIDGET_H
/** @file
* This file is Skrooge plugin for monthly report.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "ui_skgmonthlyboardwidget.h"
#include "skgwidget.h"

/**
 * This file is Skrooge plugin for monthly report
 */
class SKGMonthlyBoardWidget : public SKGWidget
{
    Q_OBJECT

public:
    /**
     * Default Constructor
     */
    SKGMonthlyBoardWidget (SKGDocument* iDocument );

    /**
     * Default Destructor
     */
    virtual ~SKGMonthlyBoardWidget();

    /**
     * Get the current state
     * MUST BE OVERWRITTEN
     * @return a string containing all information needed to set the same state.
     * Could be an XML stream
     */
    virtual QString getState();

    /**
     * Set the current state
     * MUST BE OVERWRITTEN
     * @param iState must be interpreted to set the state of the widget
     */
    virtual void setState(const QString& iState);

private slots:
    void onModified();

private:
    Q_DISABLE_COPY ( SKGMonthlyBoardWidget );

    Ui::skgmonthlyboardwidget ui;;
    int mode;
};

#endif // SKGMONTHLYBOARDWIDGET_H

==> skrooge_0.8.1.orig.tar.bz2: skrooge-0.8.1/skrooge_monthly/skgmonthlyboardwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGMONTHLYBOARDWIDGET_H
#define SKGMONTHLYBOARDWIDGET_H
/** @file
* This file is Skrooge plugin for monthly report.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "ui_skgmonthlyboardwidget.h"
#include "skgwidget.h"

#include <QTimer>
/**
 * This file is Skrooge plugin for monthly report
 */
class SKGMonthlyBoardWidget : public SKGWidget
{
    Q_OBJECT

public:
    /**
     * Default Constructor
     */
    SKGMonthlyBoardWidget(SKGDocument* iDocument);

    /**
     * Default Destructor
     */
    virtual ~SKGMonthlyBoardWidget();

    /**
     * Get the current state
     * MUST BE OVERWRITTEN
     * @return a string containing all information needed to set the same state.
     * Could be an XML stream
     */
    virtual QString getState();

    /**
     * Set the current state
     * MUST BE OVERWRITTEN
     * @param iState must be interpreted to set the state of the widget
     */
    virtual void setState(const QString& iState);

private Q_SLOTS:
    void onModified();
    void onOpen(const QString& iLink);

private:
    Q_DISABLE_COPY(SKGMonthlyBoardWidget);

    Ui::skgmonthlyboardwidget ui;
    int m_mode;
    QTimer m_timer;
};

#endif // SKGMONTHLYBOARDWIDGET_H
